@@ -3,7 +3,8 @@ import pandas as pd
 
 def read_data(path):
     """ 
-    Load data from a CSV or Excel file and return it as a pandas DataFrame.
+    Description:    
+        Load data from a CSV or Excel file and return it as a pandas DataFrame.
 
     Parameters:
         path (str): The path to the CSV or Excel file containing the data.
@@ -15,6 +16,16 @@ def read_data(path):
         ValueError: If the file extension is not supported (only .csv and .xlsx/.xls are allowed).
         FileNotFoundError: If the file specified by the path does not exist.
         Exception: For any other unexpected errors during data loading.
+
+    Example:
+        >>> data_frame = read_data('data.csv')
+        >>> data_frame.head()
+              Column1  Column2
+        0       1        10
+        1       2        15
+        2       3        20
+        3       4        25
+        4       5        30
     """
         
     # Extract file extension
